@@ -1,4 +1,5 @@
 BASE16 = "0123456789ABCDEF"
+BASE32 = "234567ABCDEFGHIJKLMNOPQRSTUVWXYZ"
 BASE36 = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
 BASE52 = "0123456789BCDFGHJKLMNPQRSTVWXYZbcdfghjklmnpqrstvwxyz"
 BASE56 = "23456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnpqrstuvwxyz"
@@ -10,4 +11,4 @@ BASE94 = (
     "[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~"
 )
 
-__all__ = (BASE16, BASE36, BASE52, BASE56, BASE58, BASE62, BASE64, BASE94)
+__all__ = (BASE16, BASE32, BASE36, BASE52, BASE56, BASE58, BASE62, BASE64, BASE94)
